# acceldata SDK

Acceldata SDK for instrumenting support in [ADOC](https://docs.acceldata.io/documentation/adoc-architecture-an-overview).

Refer to the [documentation](https://docs.acceldata.io/documentation/python) for details.